export Package — Camelot documentation

### Navigation

- index
- modules |
- Camelot documentation »

# export Package

## `export` Package

## `desktop_service` Module

`camelot.view.export.desktop_service.` `open_html_in_desktop_service`(html)

## `excel` Module

`camelot.view.export.excel.` `open_data_with_excel`(title, headerList, dataList)

`camelot.view.export.excel.` `write_data_to_excel`(filename, title, headerList, data_list)

  @param filename: the file to which to save the exported excel @param title: title to put in the first row of the genarated excel file @param headerList: list of header definitions @param data_list: list or generator with the row data

## `outlook` Module

`camelot.view.export.outlook.` `logger` = <logging.Logger object at 0xc6e184c>

  Functions to send files by email using outlook

  After http://win32com.goermezer.de/content/view/227/192/

`camelot.view.export.outlook.` `open_html_in_outlook`(html)

## `word` Module

`camelot.view.export.word.` `open_document_in_word`(filename)

  Try to open a document using word and return the word application com object if succeeded :return: (word, doc) a tuple of the com objects pointing to the word application, and the opened document. returns (None, None) if unable to open document using word

`camelot.view.export.word.` `open_html_in_word`(html, template='/home/tw55413/workspaces/camelot/svn/trunk/camelot/art/empty_document.doc', pre_processor=<function <lambda> at 0xca40ed4>, post_processor=<function <lambda> at 0xca40e64>)

  Open MS Word through COM objects and import the specified html into a new document. @param html: the html to import @param template: the empty word document in which to import the html @param post_processor: a function that will be called before importing the html, with as its argument the COM Document. @param post_processor: a function that will be called after importing the html, with as its argument the COM Document.

`camelot.view.export.word.` `open_stream_in_word`()

### Navigation

- index
- modules |
- Camelot documentation »

Comments
blog comments powered by Disqus